<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\TestFixture;

use PHPUnit\Framework\TestCase;

final class CoverageFunctionParenthesesWhitespaceTest extends TestCase
{
    /**
     * @covers ::globalFunction ( )
     *
     * @uses ::globalFunction ( )
     */
    public function testSomething(): void
    {
        globalFunction();
    }
}
